[−][src]Struct sized_chunks::bitmap::Bitmap
A compact array of bits.
The type used to store the bitmap will be the minimum unsigned integer type
required to fit the number of bits, from u8 to u128. If the size exceeds
128, an array of u128 will be used, sized as appropriately. The maximum
supported size is currently 1024, represented by an array [u128; 8].
Examples
let mut bitmap = Bitmap::<U10>::new(); assert_eq!(bitmap.set(5, true), false); assert_eq!(bitmap.set(5, true), true); assert_eq!(bitmap.get(5), true); assert_eq!(bitmap.get(6), false); assert_eq!(bitmap.len(), 1); assert_eq!(bitmap.set(3, true), false); assert_eq!(bitmap.len(), 2); assert_eq!(bitmap.first_index(), Some(3));
Methods
impl<Size: Bits> Bitmap<Size>[src]
pub fn new() -> Self[src]
Construct an empty bitmap.
pub fn len(self) -> usize[src]
Count the number of true bits in the bitmap.
pub fn is_empty(self) -> bool[src]
Test if the bitmap contains only false bits.
pub fn get(self, index: usize) -> bool[src]
Get the value of the bit at a given index.
pub fn set(&mut self, index: usize, value: bool) -> bool[src]
Set the value of the bit at a given index.
Returns the previous value of the bit.
pub fn first_index(self) -> Option<usize>[src]
Find the index of the first true bit in the bitmap.