pub struct SliceMut<'a, A, const N: usize> { /* private fields */ }Expand description
An indexable representation of a mutable subset of a RingBuffer.
Implementations
Sourceimpl<'a, A: 'a, const N: usize> SliceMut<'a, A, N>
impl<'a, A: 'a, const N: usize> SliceMut<'a, A, N>
Sourcepub unsafe fn get_unchecked(&self, index: usize) -> &A
pub unsafe fn get_unchecked(&self, index: usize) -> &A
Get an unchecked reference to the value at the given index.
Safety
You must ensure the index is not out of bounds.
Sourcepub unsafe fn get_unchecked_mut(&mut self, index: usize) -> &mut A
pub unsafe fn get_unchecked_mut(&mut self, index: usize) -> &mut A
Get an unchecked mutable reference to the value at the given index.
Safety
You must ensure the index is not out of bounds.
Sourcepub fn iter(&self) -> Iter<'_, A, N> ⓘ
pub fn iter(&self) -> Iter<'_, A, N> ⓘ
Get an iterator over references to the items in the slice in order.
Sourcepub fn iter_mut(&mut self) -> IterMut<'_, A, N> ⓘ
pub fn iter_mut(&mut self) -> IterMut<'_, A, N> ⓘ
Get an iterator over mutable references to the items in the slice in order.
Sourcepub fn slice<R: RangeBounds<usize>>(self, range: R) -> SliceMut<'a, A, N>
pub fn slice<R: RangeBounds<usize>>(self, range: R) -> SliceMut<'a, A, N>
Create a subslice of this slice.
This consumes the slice. Because the slice works like a mutable
reference, you can only have one slice over a given subset of a
RingBuffer at any one time, so that’s just how it’s got to be.
Sourcepub fn split_at(self, index: usize) -> (SliceMut<'a, A, N>, SliceMut<'a, A, N>)
pub fn split_at(self, index: usize) -> (SliceMut<'a, A, N>, SliceMut<'a, A, N>)
Split the slice into two subslices at the given index.
Sourcepub fn to_owned(&self) -> RingBuffer<A, N>where
A: Clone,
pub fn to_owned(&self) -> RingBuffer<A, N>where
A: Clone,
Construct a new RingBuffer by copying the elements in this slice.