[−][src]Module sized_chunks::types
Helper types for chunks.
Traits
| Bits | A type level number signifying the number of bits in a bitmap. |
| ChunkLength | A trait used to decide the size of an array. |
Helper types for chunks.
| Bits | A type level number signifying the number of bits in a bitmap. |
| ChunkLength | A trait used to decide the size of an array. |